@@ -1,5 +1,3 @@
-{-# LANGUAGE CPP #-}
-
 module Main where
 
 import GHC.RTS.Events
@@ -15,22 +13,31 @@ import qualified Data.ByteString.Lazy as BL
 import System.Environment (getArgs)
 import Data.Either (rights)
 import qualified Data.Map as M
+import Data.Version (showVersion)
+import qualified Paths_ghc_events as P
 import System.IO
 import System.Exit
 
+
 main :: IO ()
 main = getArgs >>= command
 
 command :: [String] -> IO ()
+command ["--version"] = putStrLn $ "ghc-events version: " ++ showVersion P.version
+
 command ["--help"] = putStr usage
 
 command ["inc", file] = printEventsIncremental False file
 
 command ["inc", "force", file] = printEventsIncremental True file
 
+command ["show", "--pretty-time", file] = do
+    evtLog <- readLogOrDie file
+    putStrLn $ ppEventLog PrettyTime evtLog
+
 command ["show", file] = do
     evtLog <- readLogOrDie file
-    putStrLn $ ppEventLog evtLog
+    putStrLn $ ppEventLog RawTime evtLog
 
 command ["show", "threads", file] = do
     eventLog <- readLogOrDie file
@@ -44,7 +51,7 @@ command ["show", "threads", file] = do
     putStrLn "Thread Indexed Events:"
     putStrLn . showMap
       ((++ "\n") . show)
-      (unlines . map (("  " ++) . ppEvent eventTypeMap)) $
+      (unlines . map (("  " ++) . ppEvent RawTime eventTypeMap)) $
         threadMap
 
 command ["show", "caps", file] = do
@@ -58,7 +65,7 @@ command ["show", "caps", file] = do
     putStrLn "Cap Indexed Events:"
     putStrLn . showMap
       ((++ "\n") . show)
-      (unlines . map (("  " ++) . ppEvent eventTypeMap)) $
+      (unlines . map (("  " ++) . ppEvent RawTime eventTypeMap)) $
         capMap
 
 command ["merge", out, file1, file2] = do
@@ -188,6 +195,7 @@ usage = unlines $ map pad strings
     align = 4 + (maximum . map (length . fst) $ strings)
     pad (x, y) = zipWith const (x ++ repeat ' ') (replicate align ()) ++ y
     strings = [ ("ghc-events --help:",                     "Display this help.")
+              , ("ghc-events --version",                   "Print the version of ghc-events.")
               , ("ghc-events inc <file>:",                 "Pretty print an event log incrementally")
               , ("ghc-events inc force <file>:",           "Pretty print an event log incrementally. Retry on incomplete input (aka 'tail -f').")
               , ("ghc-events show <file>:",                "Pretty print an event log.")
@@ -242,8 +250,3 @@ showMap showKey showValue m =
   concat $ zipWith (++)
     (map showKey . M.keys $ m :: [String])
     (map (showValue . (M.!) m) . M.keys $ m :: [String])
-
-#if !MIN_VERSION_base(4,8,0)
-die :: String -> IO a
-die err = hPutStrLn stderr err >> exitFailure
-#endif
