@@ -435,7 +435,7 @@ data EventInfo
                        }
 
   | ProfSampleCostCentre
-                       { profCapset :: !Capset
+                       { profCap :: !CapNo
                        , profTicks :: !Word64
                        , profStackDepth :: !Word8
                        , profCcsStack :: !(VU.Vector Word32)
@@ -457,11 +457,19 @@ data EventInfo
   | ConcUpdRemSetFlush { cap    :: {-# UNPACK #-}!Int
                        }
   | NonmovingHeapCensus
-                       { nonmovingCensusBlkSize :: !Word8
+                       { nonmovingCensusBlkSize :: !Word16
                        , nonmovingCensusActiveSegs :: !Word32
                        , nonmovingCensusFilledSegs :: !Word32
                        , nonmovingCensusLiveBlocks :: !Word32
                        }
+  | NonmovingPrunedSegments
+                       { -- | The number of pruned segments.
+                         nonmovingPrunedSegments :: !Word32
+                       -- | The number of leftover free segments.
+                       -- These could not be pruned as they belong to megablocks
+                       -- with at least one non-free segment.
+                       , nonmovingFreeSegments :: !Word32
+                       }
   | TickyCounterDef
                        { tickyCtrDefId      :: !Word64
                        , tickyCtrDefArity   :: !Word16
@@ -633,6 +641,7 @@ data HeapProfBreakdown
   | HeapProfBreakdownBiography
   | HeapProfBreakdownClosureType
   | HeapProfBreakdownInfoTable
+  | HeapProfBreakdownEra
   deriving Show
 
 instance Binary HeapProfBreakdown where
@@ -647,6 +656,7 @@ instance Binary HeapProfBreakdown where
       6 -> return HeapProfBreakdownBiography
       7 -> return HeapProfBreakdownClosureType
       8 -> return HeapProfBreakdownInfoTable
+      9 -> return HeapProfBreakdownEra
       _ -> fail $ "Unknown HeapProfBreakdown: " ++ show n
   put breakdown = put $ case breakdown of
     HeapProfBreakdownCostCentre -> (1 :: Word32)
@@ -657,6 +667,9 @@ instance Binary HeapProfBreakdown where
     HeapProfBreakdownBiography -> 6
     HeapProfBreakdownClosureType -> 7
     HeapProfBreakdownInfoTable -> 8
+    HeapProfBreakdownEra -> 9
+
+
 
 newtype HeapProfFlags = HeapProfFlags Word8
   deriving (Show, Binary)
