@@ -52,6 +52,7 @@ module GHC.RTS.Events (
        buildEventTypeMap,
 
        -- * Printing
+       TimeFormat(..),
        printEventsIncremental,
        showEventInfo, buildEventInfo,
        showThreadStopStatus,
@@ -95,11 +96,6 @@ import GHC.RTS.EventTypes
 import GHC.RTS.Events.Binary
 import GHC.RTS.Events.Incremental
 
-#if !MIN_VERSION_base(4, 8, 0)
-import Data.Foldable (foldMap)
-import Data.Monoid (mempty)
-#endif
-
 #if !MIN_VERSION_base(4, 11, 0)
 import Data.Monoid ((<>))
 #endif
@@ -493,7 +489,7 @@ buildEventInfo spec' =
           <> ", label " <> TB.fromText heapProfLabel
 
         ProfSampleCostCentre {..} ->
-          "cap no " <> TB.decimal profCapset
+          "cap no " <> TB.decimal profCap
           <> ", prof sample " <> TB.decimal profTicks
           <> ", cost centre stack " <> buildCostCentreStack profCcsStack
 
@@ -519,10 +515,14 @@ buildEventInfo spec' =
         ConcUpdRemSetFlush {..}  ->
           "update remembered set flushed by " <> TB.decimal cap
         NonmovingHeapCensus {..}  ->
-          "nonmoving heap census " <> TB.decimal (2^nonmovingCensusBlkSize :: Int)
+          "nonmoving heap census " <> TB.decimal nonmovingCensusBlkSize
           <> ": " <> TB.decimal nonmovingCensusActiveSegs <> " active segments"
           <> ", " <> TB.decimal nonmovingCensusFilledSegs <> " filled segments"
           <> ", " <> TB.decimal nonmovingCensusLiveBlocks <> " live blocks"
+        NonmovingPrunedSegments {..} ->
+          "nonmoving segments pruned: "
+           <> TB.decimal nonmovingPrunedSegments <> " pruned segments, "
+           <> TB.decimal nonmovingFreeSegments <> " free segments retained"
         TickyCounterDef {..}  ->
           "ticky counter definition " <> TB.decimal tickyCtrDefId
           <> ", " <>  "arity: " <> TB.decimal tickyCtrDefArity
@@ -542,7 +542,7 @@ replaceUnprintableWith
   :: Char -- ^ Replacement character
   -> B.ByteString -- ^ Binary message which may contain unprintable bytes
   -> T.Text
-replaceUnprintableWith replacement = T.map replace . TE.decodeUtf8With (\_ _ -> Just replacement) 
+replaceUnprintableWith replacement = T.map replace . TE.decodeUtf8With (\_ _ -> Just replacement)
   where
     replace c
       | isPrint c = c
@@ -596,17 +596,21 @@ showHeapProfBreakdown breakdown = case breakdown of
   HeapProfBreakdownBiography -> "biography"
   HeapProfBreakdownClosureType -> "closure type"
   HeapProfBreakdownInfoTable -> "info table"
+  HeapProfBreakdownEra -> "era"
 
-ppEventLog :: EventLog -> String
-ppEventLog = TL.unpack . TB.toLazyText . buildEventLog
+-- | How to format event timestamps
+data TimeFormat = RawTime | PrettyTime
 
-buildEventLog :: EventLog -> TB.Builder
-buildEventLog (EventLog (Header ets) (Data es)) =
+ppEventLog :: TimeFormat -> EventLog -> String
+ppEventLog time_fmt = TL.unpack . TB.toLazyText . buildEventLog time_fmt
+
+buildEventLog :: TimeFormat -> EventLog -> TB.Builder
+buildEventLog time_fmt (EventLog (Header ets) (Data es)) =
   "Event Types:\n"
   <> foldMap (\evType -> buildEventType evType <> "\n") ets
   <> "\n"
   <> "Events:\n"
-  <> foldMap (\ev -> buildEvent imap ev <> "\n") sorted
+  <> foldMap (\ev -> buildEvent time_fmt imap ev <> "\n") sorted
   where
     imap = buildEventTypeMap ets
     sorted = sortEvents es
@@ -622,14 +626,16 @@ buildEventType (EventType num dsc msz) =
 
 -- | Pretty prints an 'Event', with clean handling for 'UnknownEvent'
 ppEvent
-  :: IntMap EventType -- ^ Look up @'UnknownEvent'.'ref'@ to find a suitable description.
+  :: TimeFormat
+  -> IntMap EventType -- ^ Look up @'UnknownEvent'.'ref'@ to find a suitable description.
   -> Event
   -> String
-ppEvent imap = TL.unpack . TB.toLazyText . buildEvent imap
+ppEvent time_fmt imap =
+  TL.unpack . TB.toLazyText . buildEvent time_fmt imap
 
-buildEvent :: IntMap EventType -> Event -> TB.Builder
-buildEvent imap Event {..} =
-  TB.decimal evTime
+buildEvent :: TimeFormat -> IntMap EventType -> Event -> TB.Builder
+buildEvent time_fmt imap Event {..} =
+  buildTime time_fmt evTime
   <> ": "
   <> maybe "" (\c -> "cap " <> TB.decimal c <> ": ") evCap
   <> case evSpec of
@@ -637,6 +643,29 @@ buildEvent imap Event {..} =
       maybe "" (TB.fromText . desc) $ IM.lookup (fromIntegral ref) imap
     _ -> buildEventInfo evSpec
 
+buildTime :: TimeFormat -> Word64 -> TB.Builder
+buildTime RawTime t = TB.decimal t
+buildTime PrettyTime t =
+     rJustDecimal secs  <> "s "
+  <> rJustDecimal msecs <> "ms "
+  <> rJustDecimal usecs
+  <> "."
+  <> lJustDecimal nsecs''  <> "us"
+  where
+    (secs, nsecs) = t `divMod` (1000*1000*1000)
+    (msecs, nsecs') = nsecs `divMod` (1000*1000)
+    (usecs, nsecs'') = nsecs' `divMod` 1000
+
+    padSpaces :: Word64 -> TB.Builder
+    padSpaces n
+      | n < 10    = "  "
+      | n < 100   = " "
+      | otherwise = mempty
+
+    -- decimal numbers justified to three columns
+    rJustDecimal n = padSpaces n <> TB.decimal n
+    lJustDecimal n = TB.decimal n <> padSpaces n
+
 buildEvent' :: Event -> TB.Builder
 buildEvent' Event {..} =
    TB.decimal evTime
