@@ -1,6 +1,7 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE ViewPatterns #-}
+{-# LANGUAGE TypeApplications #-}
 module GHC.RTS.Events.Binary
   ( -- * Readers
     getHeader
@@ -343,13 +344,27 @@ standardParsers = [
       cap <- get :: Get CapNo
       return ConcUpdRemSetFlush{ cap = fromIntegral cap }
     )),
+ -- Before GHC issue 23340 event where we are given the logarithm of the block size
  (FixedSizeParser EVENT_NONMOVING_HEAP_CENSUS 13 (do -- (blk_size, active_segs, filled_segs, live_blks)
-      nonmovingCensusBlkSize <- get :: Get Word8
+      nonmovingCensusLogBlkSize <- get :: Get Word8
+      let nonmovingCensusBlkSize = 2^nonmovingCensusLogBlkSize
       nonmovingCensusActiveSegs <- get :: Get Word32
       nonmovingCensusFilledSegs <- get :: Get Word32
       nonmovingCensusLiveBlocks <- get :: Get Word32
       return NonmovingHeapCensus{..}
     )),
+ (FixedSizeParser EVENT_NONMOVING_HEAP_CENSUS 14 (do -- (blk_size, active_segs, filled_segs, live_blks)
+      nonmovingCensusBlkSize <- get :: Get Word16
+      nonmovingCensusActiveSegs <- get :: Get Word32
+      nonmovingCensusFilledSegs <- get :: Get Word32
+      nonmovingCensusLiveBlocks <- get :: Get Word32
+      return NonmovingHeapCensus{..}
+    )),
+ (FixedSizeParser EVENT_NONMOVING_PRUNED_SEGMENTS 8 (do -- (pruned_segments, free_segments)
+      nonmovingPrunedSegments <- get :: Get Word32
+      nonmovingFreeSegments <- get :: Get Word32
+      return NonmovingPrunedSegments{..}
+    )),
 
  (FixedSizeParser EVENT_CREATE_THREAD sz_tid (do  -- (thread)
       t <- get
@@ -742,7 +757,7 @@ timeProfParsers = [
     return $! ProfBegin{..}
   , VariableSizeParser EVENT_PROF_SAMPLE_COST_CENTRE $ do
     payloadLen <- get :: Get Word16
-    profCapset <- get
+    profCap <- fromIntegral @Int32 @CapNo <$> get
     profTicks <- get
     profStackDepth <- get
     profCcsStack <- VU.replicateM (fromIntegral profStackDepth) get
@@ -982,6 +997,7 @@ eventTypeNum e = case e of
     ConcSweepEnd {} -> EVENT_CONC_SWEEP_END
     ConcUpdRemSetFlush {} -> EVENT_CONC_UPD_REM_SET_FLUSH
     NonmovingHeapCensus {} -> EVENT_NONMOVING_HEAP_CENSUS
+    NonmovingPrunedSegments {} -> EVENT_NONMOVING_PRUNED_SEGMENTS
     TickyCounterDef {} -> EVENT_TICKY_COUNTER_DEF
     TickyCounterSample {} -> EVENT_TICKY_COUNTER_SAMPLE
     InfoTableProv {} -> EVENT_IPE
@@ -1411,7 +1427,7 @@ putEventSpec HeapProfSampleString {..} = do
     putE $ T.unpack heapProfLabel
 
 putEventSpec ProfSampleCostCentre {..} = do
-    putE profCapset
+    putE $ fromIntegral @CapNo @Int16 profCap
     putE profTicks
     putE profStackDepth
     VU.mapM_ putE profCcsStack
@@ -1437,6 +1453,9 @@ putEventSpec NonmovingHeapCensus {..} = do
     putE nonmovingCensusActiveSegs
     putE nonmovingCensusFilledSegs
     putE nonmovingCensusLiveBlocks
+putEventSpec NonmovingPrunedSegments {..} = do
+    putE nonmovingPrunedSegments
+    putE nonmovingFreeSegments
 putEventSpec TickyCounterDef {..} = do
     putE tickyCtrDefId
     putE tickyCtrDefArity
