@@ -4,6 +4,8 @@ files :: [FilePath]
 files = map ("test/"++)
     [ "nonmoving-gc.eventlog"
     , "nonmoving-gc-census.eventlog"
+    , "nonmoving-gc-census-T23340.eventlog"
+    , "nonmoving-gc-pruned-segments.eventlog"
     , "parallelTest.eventlog"
     , "sleep.h.eventlog"
     , "sleep.hC.eventlog"
